==> qmmp_1.1.6.orig.tar.bz2: qmmp-1.1.6/src/plugins/Output/oss4/translations/oss4_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>OutputOSS4Factory</name>
    <message>
        <location filename="../outputoss4factory.cpp" line="37"/>
        <source>OSS4 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="57"/>
        <source>About OSS4 Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="58"/>
        <source>Qmmp OSS4 Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS4 Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Output/oss4/translations/oss4_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>OutputOSS4Factory</name>
    <message>
        <location filename="../outputoss4factory.cpp" line="37"/>
        <source>OSS4 Plugin</source>
        <translation>Estensione OSS4</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="57"/>
        <source>About OSS4 Output Plugin</source>
        <translation>Informazioni sull&apos;estensione d&apos;uscita OSS4</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="58"/>
        <source>Qmmp OSS4 Output Plugin</source>
        <translation>Estensione d&apos;uscita OSS4 per Qmmp</translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS4 Plugin Settings</source>
        <translation>Impostazioni dell&apos;estensione OSS4</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Device:</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
</context>
</TS>
